@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "ldapimportexportplugininterface.h"
@@ -23,23 +10,21 @@
 #include <QAction>
 #include <QPointer>
 #include <PimCommonAkonadi/LdapSearchDialog>
-#include "../shared/importexportengine.h"
+#include <KAddressBookImportExport/ImportExportEngine>
 
 LDapImportExportPluginInterface::LDapImportExportPluginInterface(QObject *parent)
-    : KAddressBookImportExport::KAddressBookImportExportPluginInterface(parent)
+    : KAddressBookImportExport::PluginInterface(parent)
 {
 }
 
-LDapImportExportPluginInterface::~LDapImportExportPluginInterface()
-{
-}
+LDapImportExportPluginInterface::~LDapImportExportPluginInterface() = default;
 
 void LDapImportExportPluginInterface::createAction(KActionCollection *ac)
 {
     QAction *action = ac->addAction(QStringLiteral("file_import_ldap"));
     action->setText(i18n("Import From LDAP server..."));
     action->setWhatsThis(i18n("Import contacts from an LDAP server."));
-    setImportActions(QList<QAction *>() << action);
+    setImportActions({action});
     connect(action, &QAction::triggered, this, &LDapImportExportPluginInterface::slotImportLdap);
 }
 
@@ -62,7 +47,7 @@ void LDapImportExportPluginInterface::slotImportLdap()
 
 void LDapImportExportPluginInterface::importLdap()
 {
-    KAddressBookImportExport::KAddressBookImportExportContactList contactList;
+    KAddressBookImportExport::ContactList contactList;
     QPointer<PimCommon::LdapSearchDialog> dlg = new PimCommon::LdapSearchDialog(parentWidget());
 
     if (dlg->exec()) {
@@ -70,7 +55,7 @@ void LDapImportExportPluginInterface::importLdap()
     }
 
     delete dlg;
-    ImportExportEngine *engine = new ImportExportEngine(this);
+    auto *engine = new KAddressBookImportExport::ImportExportEngine(this);
     engine->setContactList(contactList);
     engine->setDefaultAddressBook(defaultCollection());
     engine->importContacts();
