@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "selectmaildialog.h"
@@ -24,10 +11,13 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 
+namespace {
+static const char myConfigGroupName[] = "SelectMailDialog";
+}
 SelectMailDialog::SelectMailDialog(QWidget *parent)
     : QDialog(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
     mSelectMailWidget = new SelectMailWidget(this);
     mSelectMailWidget->setObjectName(QStringLiteral("selectmailwidget"));
@@ -59,7 +49,7 @@ void SelectMailDialog::accept()
 
 void SelectMailDialog::readConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "SelectMailDialog");
+    KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
     const QSize size = grp.readEntry("Size", QSize(300, 200));
     if (size.isValid()) {
         resize(size);
@@ -68,7 +58,7 @@ void SelectMailDialog::readConfig()
 
 void SelectMailDialog::writeConfig()
 {
-    KConfigGroup grp(KSharedConfig::openConfig(), "SelectMailDialog");
+    KConfigGroup grp(KSharedConfig::openConfig(), myConfigGroupName);
     grp.writeEntry("Size", size());
     grp.sync();
 }
