@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "quicktextplugineditorinterface.h"
@@ -31,8 +18,8 @@
 
 QuickTextPluginEditorInterface::QuickTextPluginEditorInterface(QObject *parent)
     : MessageComposer::PluginEditorInterface(parent)
+    , mModel(MailCommon::SnippetsModel::instance())
 {
-    mModel = MailCommon::SnippetsModel::instance();
     updateSnippetsInfo();
 }
 
@@ -47,7 +34,7 @@ void QuickTextPluginEditorInterface::updateSnippetsInfo()
 
 void QuickTextPluginEditorInterface::createAction(KActionCollection *ac)
 {
-    QuickTextMenu *quickTextMenu = new QuickTextMenu(parentWidget(), this);
+    auto *quickTextMenu = new QuickTextMenu(parentWidget(), this);
     quickTextMenu->setPluginComposerInterface(composerInterface());
     connect(quickTextMenu, &QuickTextMenu::insertText, this, &QuickTextPluginEditorInterface::insertText);
     QAction *action = new QAction(i18n("Variables"), this);
@@ -81,7 +68,7 @@ bool QuickTextPluginEditorInterface::processProcessKeyEvent(QKeyEvent *e)
     if (e->key() == Qt::Key_Tab) {
         if (!richTextEditor()->textCursor().hasSelection()) {
             //const QTextCharFormat initialTextFormat = richTextEditor()->textCursor().charFormat();
-            int position = richTextEditor()->textCursor().position();
+            const int position = richTextEditor()->textCursor().position();
             QTextCursor cur = richTextEditor()->textCursor();
             selectPreviousWord(cur, position);
             const QString selectedWord = cur.selectedText();
