@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "languagetoolconfigwidget.h"
@@ -36,17 +23,17 @@ LanguageToolConfigWidget::LanguageToolConfigWidget(QWidget *parent)
     : QWidget(parent)
 {
     mLanguageToolUpdateCombobox = new LanguageToolUpdateComboBox(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
 
     mUseLocalInstance = new QCheckBox(i18n("Use Local Instance"), this);
     mUseLocalInstance->setObjectName(QStringLiteral("uselocalinstance"));
     mainLayout->addWidget(mUseLocalInstance);
 
-    QHBoxLayout *instanceLayout = new QHBoxLayout;
+    auto *instanceLayout = new QHBoxLayout;
     instanceLayout->setObjectName(QStringLiteral("instancelayout"));
-    instanceLayout->setContentsMargins(0, 0, 0, 0);
+    instanceLayout->setContentsMargins({});
     mInstancePathLabel = new QLabel(i18n("Instance Path:"), this);
     mInstancePathLabel->setObjectName(QStringLiteral("instancepath"));
     mInstancePathLabel->setEnabled(false);
@@ -59,12 +46,9 @@ LanguageToolConfigWidget::LanguageToolConfigWidget(QWidget *parent)
     instanceLayout->addWidget(mInstancePath);
     mainLayout->addLayout(instanceLayout);
 
-    connect(mUseLocalInstance, &QCheckBox::clicked, this, [this](bool b) {
-        updateWidgets(b);
-    }
-            );
+    connect(mUseLocalInstance, &QCheckBox::clicked, this, &LanguageToolConfigWidget::updateWidgets);
 
-    QHBoxLayout *languageLayout = new QHBoxLayout;
+    auto *languageLayout = new QHBoxLayout;
     languageLayout->setObjectName(QStringLiteral("languagelayout"));
     QLabel *languageLabel = new QLabel(i18n("Language:"), this);
     languageLabel->setObjectName(QStringLiteral("languageLabel"));
@@ -76,7 +60,7 @@ LanguageToolConfigWidget::LanguageToolConfigWidget(QWidget *parent)
     mLanguageToolUpdateCombobox->setLanguageToolCombobox(mLanguageToolCombobox);
     mLanguageToolUpdateCombobox->setParentWidget(this);
 
-    QToolButton *refreshButton = new QToolButton(this);
+    auto *refreshButton = new QToolButton(this);
     refreshButton->setObjectName(QStringLiteral("refreshbutton"));
     refreshButton->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     refreshButton->setToolTip(i18n("Refresh"));
