@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "languagetoolupdatecombobox.h"
@@ -40,7 +27,7 @@ LanguageToolUpdateComboBox::~LanguageToolUpdateComboBox()
 
 void LanguageToolUpdateComboBox::checkListOfLanguagesFromSpecificPath(const QString &url)
 {
-    LanguageToolGetListOfLanguageJob *job = new LanguageToolGetListOfLanguageJob(this);
+    auto *job = new LanguageToolGetListOfLanguageJob(this);
     job->setUrl(LanguageToolManager::convertToLanguagePath(url));
     job->setNetworkAccessManager(LanguageToolManager::self()->networkAccessManager());
     connect(job, &LanguageToolGetListOfLanguageJob::finished, this, &LanguageToolUpdateComboBox::slotGetLanguagesFinished);
@@ -50,7 +37,7 @@ void LanguageToolUpdateComboBox::checkListOfLanguagesFromSpecificPath(const QStr
 
 void LanguageToolUpdateComboBox::refreshListOfLanguages()
 {
-    LanguageToolGetListOfLanguageJob *job = new LanguageToolGetListOfLanguageJob(this);
+    auto *job = new LanguageToolGetListOfLanguageJob(this);
     job->setUrl(LanguageToolManager::self()->languageToolLanguagesPath());
     job->setNetworkAccessManager(LanguageToolManager::self()->networkAccessManager());
     connect(job, &LanguageToolGetListOfLanguageJob::finished, this, &LanguageToolUpdateComboBox::slotGetLanguagesFinished);
