@@ -1,24 +1,11 @@
 /*
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2007 KovoKs <kovoks@kovoks.nl>
+    SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2007 KovoKs <kovoks@kovoks.nl>
 
     Based on KMail code by:
-    Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+    SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sendmailjob.h"
@@ -27,15 +14,14 @@
 
 #include <KLocalizedString>
 #include <KShell>
-#include <QProcess>
 #include <QBuffer>
 
 using namespace MailTransport;
 
 SendmailJob::SendmailJob(Transport *transport, QObject *parent)
     : TransportJob(transport, parent)
+    , mProcess(new QProcess(this))
 {
-    mProcess = new QProcess(this);
     connect(mProcess, qOverload<int, QProcess::ExitStatus>(&QProcess::finished), this, &SendmailJob::sendmailExited);
     connect(mProcess, qOverload<QProcess::ProcessError>(&QProcess::errorOccurred),
             this, &SendmailJob::receivedError);
@@ -92,6 +78,5 @@ void SendmailJob::receivedStdErr()
 bool SendmailJob::doKill()
 {
     delete mProcess;
-    mProcess = nullptr;
     return true;
 }
