@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <MessageViewer/MessagePartRendererBase>
@@ -61,18 +48,18 @@ public:
         c.insert(QStringLiteral("block"), msgPart.data());
         c.insert(QStringLiteral("showOnlyOneMimePart"), context->showOnlyOneMimePart());
         c.insert(QStringLiteral("content"), QVariant::fromValue<MessageViewer::GrantleeCallback>([=](Grantlee::OutputStream *) {
-            QString result;
+                QString result;
 #ifdef USE_DISCOUNT_LIB
-            MarkdownDiscount engine;
-            engine.setText(msgPart->text());
-            result = engine.toHtml();
+                MarkdownDiscount engine;
+                engine.setText(msgPart->text());
+                result = engine.toHtml();
 #else
-            MarkdownQTextDocument engine;
-            engine.setText(msgPart->text());
-            result = engine.toHtml();
+                MarkdownQTextDocument engine;
+                engine.setText(msgPart->text());
+                result = engine.toHtml();
 #endif
-            (*htmlWriter->stream()) << result;
-        }));
+                (*htmlWriter->stream()) << result;
+            }));
         auto t = MessageViewer::MessagePartRendererManager::self()->loadByName(QStringLiteral("textmessagepart.html"));
         Grantlee::OutputStream s(htmlWriter->stream());
         t->render(&s, &c);
