@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+  SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef NOTEEDIT_H
@@ -38,10 +27,10 @@ public:
     explicit NoteEdit(QWidget *parent = nullptr);
     ~NoteEdit() override;
 
-    Akonadi::Collection collection() const;
+    Q_REQUIRED_RESULT Akonadi::Collection collection() const;
     void setCollection(const Akonadi::Collection &value);
 
-    KMime::Message::Ptr message() const;
+    Q_REQUIRED_RESULT KMime::Message::Ptr message() const;
     void setMessage(const KMime::Message::Ptr &value);
 
     void writeConfig();
